# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['CloudInitDiskArgs', 'CloudInitDisk']

@pulumi.input_type
class CloudInitDiskArgs:
    def __init__(__self__, *,
                 meta_data: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_config: Optional[pulumi.Input[str]] = None,
                 pool: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a CloudInitDisk resource.
        :param pulumi.Input[str] meta_data: cloud-init user data.
        :param pulumi.Input[str] name: A unique name for the resource, required by libvirt.
        :param pulumi.Input[str] network_config: cloud-init network-config data.
        :param pulumi.Input[str] pool: The pool where the resource will be created.
               If not given, the `default` pool will be used.
               For user_data, network_config and meta_data parameters have a look at upstream doc:
               http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        :param pulumi.Input[str] user_data: cloud-init user data.
        """
        if meta_data is not None:
            pulumi.set(__self__, "meta_data", meta_data)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_config is not None:
            pulumi.set(__self__, "network_config", network_config)
        if pool is not None:
            pulumi.set(__self__, "pool", pool)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)

    @property
    @pulumi.getter(name="metaData")
    def meta_data(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "meta_data")

    @meta_data.setter
    def meta_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "meta_data", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A unique name for the resource, required by libvirt.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkConfig")
    def network_config(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init network-config data.
        """
        return pulumi.get(self, "network_config")

    @network_config.setter
    def network_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_config", value)

    @property
    @pulumi.getter
    def pool(self) -> Optional[pulumi.Input[str]]:
        """
        The pool where the resource will be created.
        If not given, the `default` pool will be used.
        For user_data, network_config and meta_data parameters have a look at upstream doc:
        http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        """
        return pulumi.get(self, "pool")

    @pool.setter
    def pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pool", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_data", value)


@pulumi.input_type
class _CloudInitDiskState:
    def __init__(__self__, *,
                 meta_data: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_config: Optional[pulumi.Input[str]] = None,
                 pool: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CloudInitDisk resources.
        :param pulumi.Input[str] meta_data: cloud-init user data.
        :param pulumi.Input[str] name: A unique name for the resource, required by libvirt.
        :param pulumi.Input[str] network_config: cloud-init network-config data.
        :param pulumi.Input[str] pool: The pool where the resource will be created.
               If not given, the `default` pool will be used.
               For user_data, network_config and meta_data parameters have a look at upstream doc:
               http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        :param pulumi.Input[str] user_data: cloud-init user data.
        """
        if meta_data is not None:
            pulumi.set(__self__, "meta_data", meta_data)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_config is not None:
            pulumi.set(__self__, "network_config", network_config)
        if pool is not None:
            pulumi.set(__self__, "pool", pool)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)

    @property
    @pulumi.getter(name="metaData")
    def meta_data(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "meta_data")

    @meta_data.setter
    def meta_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "meta_data", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A unique name for the resource, required by libvirt.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkConfig")
    def network_config(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init network-config data.
        """
        return pulumi.get(self, "network_config")

    @network_config.setter
    def network_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_config", value)

    @property
    @pulumi.getter
    def pool(self) -> Optional[pulumi.Input[str]]:
        """
        The pool where the resource will be created.
        If not given, the `default` pool will be used.
        For user_data, network_config and meta_data parameters have a look at upstream doc:
        http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        """
        return pulumi.get(self, "pool")

    @pool.setter
    def pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pool", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_data", value)


class CloudInitDisk(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 meta_data: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_config: Optional[pulumi.Input[str]] = None,
                 pool: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a CloudInitDisk resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] meta_data: cloud-init user data.
        :param pulumi.Input[str] name: A unique name for the resource, required by libvirt.
        :param pulumi.Input[str] network_config: cloud-init network-config data.
        :param pulumi.Input[str] pool: The pool where the resource will be created.
               If not given, the `default` pool will be used.
               For user_data, network_config and meta_data parameters have a look at upstream doc:
               http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        :param pulumi.Input[str] user_data: cloud-init user data.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CloudInitDiskArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a CloudInitDisk resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param CloudInitDiskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudInitDiskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 meta_data: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_config: Optional[pulumi.Input[str]] = None,
                 pool: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudInitDiskArgs.__new__(CloudInitDiskArgs)

            __props__.__dict__["meta_data"] = meta_data
            __props__.__dict__["name"] = name
            __props__.__dict__["network_config"] = network_config
            __props__.__dict__["pool"] = pool
            __props__.__dict__["user_data"] = user_data
        super(CloudInitDisk, __self__).__init__(
            'libvirt:index/cloudInitDisk:CloudInitDisk',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            meta_data: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_config: Optional[pulumi.Input[str]] = None,
            pool: Optional[pulumi.Input[str]] = None,
            user_data: Optional[pulumi.Input[str]] = None) -> 'CloudInitDisk':
        """
        Get an existing CloudInitDisk resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] meta_data: cloud-init user data.
        :param pulumi.Input[str] name: A unique name for the resource, required by libvirt.
        :param pulumi.Input[str] network_config: cloud-init network-config data.
        :param pulumi.Input[str] pool: The pool where the resource will be created.
               If not given, the `default` pool will be used.
               For user_data, network_config and meta_data parameters have a look at upstream doc:
               http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        :param pulumi.Input[str] user_data: cloud-init user data.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudInitDiskState.__new__(_CloudInitDiskState)

        __props__.__dict__["meta_data"] = meta_data
        __props__.__dict__["name"] = name
        __props__.__dict__["network_config"] = network_config
        __props__.__dict__["pool"] = pool
        __props__.__dict__["user_data"] = user_data
        return CloudInitDisk(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="metaData")
    def meta_data(self) -> pulumi.Output[Optional[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "meta_data")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A unique name for the resource, required by libvirt.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkConfig")
    def network_config(self) -> pulumi.Output[Optional[str]]:
        """
        cloud-init network-config data.
        """
        return pulumi.get(self, "network_config")

    @property
    @pulumi.getter
    def pool(self) -> pulumi.Output[Optional[str]]:
        """
        The pool where the resource will be created.
        If not given, the `default` pool will be used.
        For user_data, network_config and meta_data parameters have a look at upstream doc:
        http://cloudinit.readthedocs.io/en/latest/topics/datasources/nocloud.html#datasource-nocloud
        """
        return pulumi.get(self, "pool")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> pulumi.Output[Optional[str]]:
        """
        cloud-init user data.
        """
        return pulumi.get(self, "user_data")

