# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .cloud_init_disk import *
from .domain import *
from .get_network_dns_host_template import *
from .get_network_dns_srv_template import *
from .get_network_dnsmasq_options_template import *
from .ignition import *
from .network import *
from .pool import *
from .provider import *
from .volume import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_libvirt.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_libvirt.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "libvirt",
  "mod": "index/cloudInitDisk",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/cloudInitDisk:CloudInitDisk": "CloudInitDisk"
  }
 },
 {
  "pkg": "libvirt",
  "mod": "index/domain",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "libvirt",
  "mod": "index/ignition",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/ignition:Ignition": "Ignition"
  }
 },
 {
  "pkg": "libvirt",
  "mod": "index/network",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/network:Network": "Network"
  }
 },
 {
  "pkg": "libvirt",
  "mod": "index/pool",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "libvirt",
  "mod": "index/volume",
  "fqn": "pulumi_libvirt",
  "classes": {
   "libvirt:index/volume:Volume": "Volume"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "libvirt",
  "token": "pulumi:providers:libvirt",
  "fqn": "pulumi_libvirt",
  "class": "Provider"
 }
]
"""
)
